@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2024  Thomas Okken
+ * Copyright (C) 2004-2025  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -251,9 +251,8 @@ int docmd_insr(arg_struct *arg) {
     return ERR_NONE;
 }
 
-static void invrt_completion(int error, vartype *res) {
-    if (error == ERR_NONE)
-        unary_result(res);
+static void invrt_completion(vartype *res) {
+    unary_result(res);
 }
 
 int docmd_invrt(arg_struct *arg) {
@@ -553,7 +552,7 @@ int docmd_rclel(arg_struct *arg) {
         int4 n = matedit_i * cm->columns + matedit_j;
         v = new_complex(cm->array->data[2 * n],
                         cm->array->data[2 * n + 1]);
-    } else if (m->type == TYPE_LIST) {
+    } else {
         vartype_list *list = (vartype_list *) m;
         if (list->size == 0)
             return ERR_NONEXISTENT;
@@ -707,7 +706,6 @@ int docmd_rsum(arg_struct *arg) {
 
 int docmd_swap_r(arg_struct *arg) {
     vartype *m;
-    phloat xx, yy;
     int4 x, y, i;
 
     int err = matedit_get(&m);
@@ -725,25 +723,10 @@ int docmd_swap_r(arg_struct *arg) {
     if (stack[sp - 1]->type != TYPE_REAL)
         return ERR_INVALID_TYPE;
 
-    xx = ((vartype_real *) stack[sp])->x;
-    if (xx <= -2147483648.0 || xx >= 2147483648.0)
+    if (!dim_to_int4(stack[sp], &x))
         return ERR_DIMENSION_ERROR;
-    x = to_int4(xx);
-    if (x == 0)
+    if (!dim_to_int4(stack[sp - 1], &y))
         return ERR_DIMENSION_ERROR;
-    if (x < 0)
-        x = -x;
-    x--;
-
-    yy = ((vartype_real *) stack[sp - 1])->x;
-    if (yy <= -2147483648.0 || yy >= 2147483648.0)
-        return ERR_DIMENSION_ERROR;
-    y = to_int4(yy);
-    if (y == 0)
-        return ERR_DIMENSION_ERROR;
-    if (y < 0)
-        y = -y;
-    y--;
 
     if (m->type == TYPE_REALMATRIX) {
         vartype_realmatrix *rm = (vartype_realmatrix *) m;
@@ -892,7 +875,6 @@ int docmd_stoel(arg_struct *arg) {
 
 int docmd_stoij(arg_struct *arg) {
     vartype *m;
-    phloat x, y;
     int4 i, j;
 
     int err = matedit_get(&m);
@@ -908,36 +890,27 @@ int docmd_stoij(arg_struct *arg) {
     if (stack[sp - 1]->type != TYPE_REAL)
         return ERR_INVALID_TYPE;
 
-    x = ((vartype_real *) stack[sp])->x;
-    if (x <= -2147483648.0 || x >= 2147483648.0)
+    if (!dim_to_int4(stack[sp], &j))
         return ERR_DIMENSION_ERROR;
-    j = to_int4(x);
-    if (j < 0)
-        j = -j;
-
-    y = ((vartype_real *) stack[sp - 1])->x;
-    if (y <= -2147483648.0 || y >= 2147483648.0)
+    if (!dim_to_int4(stack[sp - 1], &i))
         return ERR_DIMENSION_ERROR;
-    i = to_int4(y);
-    if (i < 0)
-        i = -i;
 
     if (m->type == TYPE_REALMATRIX) {
         vartype_realmatrix *rm = (vartype_realmatrix *) m;
-        if (i == 0 || i > rm->rows || j == 0 || j > rm->columns)
+        if (i >= rm->rows || j >= rm->columns)
             return ERR_DIMENSION_ERROR;
     } else if (m->type == TYPE_COMPLEXMATRIX) {
         vartype_complexmatrix *cm = (vartype_complexmatrix *) m;
-        if (i == 0 || i > cm->rows || j == 0 || j > cm->columns)
+        if (i >= cm->rows || j >= cm->columns)
             return ERR_DIMENSION_ERROR;
     } else if (m->type == TYPE_LIST) {
         vartype_list *list = (vartype_list *) m;
-        if (i == 0 || i > list->size || j != 1)
+        if (i >= list->size || j != 0)
             return ERR_DIMENSION_ERROR;
     }
 
-    matedit_i = i - 1;
-    matedit_j = j - 1;
+    matedit_i = i;
+    matedit_j = j;
     return ERR_NONE;
 }
 
