@@ -1017,6 +1017,16 @@ int docmd_mixed(arg_struct *arg) {
     return ERR_NONE;
 }
 
+int docmd_static(arg_struct *arg) {
+    mode_menu_static = true;
+    return ERR_NONE;
+}
+
+int docmd_dynamic(arg_struct *arg) {
+    mode_menu_static = false;
+    return ERR_NONE;
+}
+
 int docmd_skip(arg_struct *arg) {
     return ERR_NO;
 }
